.. currentmodule:: Antiland

API Reference
====================

This section provides documentation for various classes in the Antiland package.

Bot
~~~~

.. automodule:: Antiland.Bot
   :members:
   :undoc-members:
   

User
~~~~~
.. autoclass:: Antiland.user.User
   :members:
   :undoc-members:
   :exclude-members: get_time get_date

Dialogue
~~~~~~~~~
.. autoclass:: Antiland.dialogue.Dialogue
   :members:

Message
~~~~~~~~~
.. autoclass:: Antiland.message.Message
   :members:
   :undoc-members: